@@ -26,7 +26,7 @@ from DeepMTP.main import TwoBranchDotProductModel
 from DeepMTP.main import TwoBranchMLPModel
 import streamlit as st
 
-class DeepMTP:
+class DeepMTP:   # pragma: no cover
 	''' Implements the training and inference logic of the DeepMTP framework. 
 	'''
 	def __init__(self, config, checkpoint_dir=None):
@@ -133,7 +133,7 @@ class DeepMTP:
 			metric_to_track=self.config['metric_to_optimize_early_stopping'] if self.config['use_early_stopping'] else self.config['metric_to_optimize_best_epoch_selection'],
 		)
 
-	def inference(self, model, dataloader, mode, epoch, return_predictions=False, verbose=False, val_progress_table=None):
+	def inference(self, model, dataloader, mode, epoch, return_predictions=False, verbose=False, val_progress_table=None):   # pragma: no cover
 		model.eval()
 		with torch.no_grad():
 			loss_arr = []
@@ -193,7 +193,7 @@ class DeepMTP:
 			else:
 				return results
 
-	def train(self, train_data, val_data, test_data, verbose=False):
+	def train(self, train_data, val_data, test_data, verbose=False):   # pragma: no cover
 		train_val_loss_chart, train_header, train_progress_table, val_header, val_progress_table, test_header, test_progress_table, final_info = st.empty(), st.empty(), st.empty(), st.empty(), st.empty(), st.empty(), st.empty(), st.empty()
 		
 		self.deepMTP_model.train()
@@ -358,10 +358,11 @@ class DeepMTP:
 			
 			train_val_loss_chart.add_rows(pd.DataFrame(np.array([train_run_story[-1][2], val_run_story[-1][2]]).reshape(1,-1), columns=['train', 'val']))
 
-		self.deepMTP_model = self.early_stopping.best_model  
+		self.deepMTP_model = self.early_stopping.get_best_model()  
 
 		# log the performance validation results of the best model
-		results_to_log = {'best_val_'+m+'_'+av: self.early_stopping.best_performance_results['val_'+m+'_'+av] for m in self.config['metrics'] for av in self.config['metrics_average'] if 'val_'+m+'_'+av in self.early_stopping.best_performance_results}
+		val_best_performance_results = self.early_stopping.get_best_performance_results()
+		results_to_log = {'best_val_'+m+'_'+av: val_best_performance_results['val_'+m+'_'+av] for m in self.config['metrics'] for av in self.config['metrics_average'] if 'val_'+m+'_'+av in val_best_performance_results}
 		if self.wandb_run is not None:
 			self.wandb_run.log(results_to_log)
 		if self.tensorboard_logger is not None:
@@ -376,10 +377,10 @@ class DeepMTP:
 		# if self.config['verbose']: print('Done')
 
 		# update test_run_story_table
-		test_run_story_table.add_row(['test', self.early_stopping.best_epoch, '-'] + [round(test_results['test_'+m+'_'+av], 4) for m in self.config['metrics'] for av in self.config['metrics_average']])
+		test_run_story_table.add_row(['test', self.early_stopping.get_best_epoch(), '-'] + [round(test_results['test_'+m+'_'+av], 4) for m in self.config['metrics'] for av in self.config['metrics_average']])
 		# update the streamlit dataframe 
 		test_header.subheader('Performance on the test set')
-		test_progress_df = pd.DataFrame(np.array(['test', self.early_stopping.best_epoch, '-'] + [round(test_results['test_'+m+'_'+av], 4) for m in self.config['metrics'] for av in self.config['metrics_average']]).reshape(1,-1), columns=run_story_header)
+		test_progress_df = pd.DataFrame(np.array(['test', self.early_stopping.get_best_epoch(), '-'] + [round(test_results['test_'+m+'_'+av], 4) for m in self.config['metrics'] for av in self.config['metrics_average']]).reshape(1,-1), columns=run_story_header)
 		test_progress_table.table(test_progress_df)
 		# update the loggers
 		results_to_log = {'test_'+m+'_'+av: test_results['test_'+m+'_'+av] for m in self.config['metrics'] for av in self.config['metrics_average']}
@@ -437,23 +438,23 @@ class DeepMTP:
 			final_info.empty()
 
 		
-		return self.early_stopping.best_performance_results
+		return val_best_performance_results
 
-	def predict(self, data, return_predictions=False, verbose=False):
+	def predict(self, data, return_predictions=False, verbose=False):   # pragma: no cover
 		self.deepMTP_model.to(self.device)
 		dataloader = DataLoader(BaseDataset(self.config, data['y'], data['X_instance'], data['X_target']), self.config['val_batchsize'], shuffle=False, num_workers=self.config['num_workers'])
 		return self.inference(self.deepMTP_model, dataloader, '', 0, return_predictions=True, verbose=verbose)
 
-	def save_model(self, verbose=False):
+	def save_model(self, verbose=False):   # pragma: no cover
 		self.config['use_tensorboard_logger'] = False
 		# if verbose: print('Saving the best model... ', end='')
 		torch.save({
-			'model_state_dict': self.early_stopping.best_model.state_dict(),
-			'optimizer_state_dict': self.early_stopping.best_optimizer_state_dict,
+			'model_state_dict': self.early_stopping.get_best_model().state_dict(),
+			'optimizer_state_dict': self.early_stopping.get_best_optimizer_state_dict(),
 			# 'optimizer_state_dict': self.optimizer.state_dict(),
 			'config': self.config
 			}, self.experiment_dir+'/model.pt')
 		# if verbose: print('Done')
 
-def initialize_mode(config):
+def initialize_mode(config):   # pragma: no cover
 	return DeepMTP(config)
\ No newline at end of file
