@@ -3,7 +3,7 @@ import numpy as np
 class EarlyStopping:
     '''Early stops the training if validation loss doesn't improve after a given patience.'''
 
-    def __init__(self, use_early_stopping, patience=7, delta=0, metric_to_track='loss', verbose=False):
+    def __init__(self, use_early_stopping, patience=7, delta=0.0, metric_to_track='loss', verbose=False):
         '''
         Args:
             patience (int): How long to wait after last time validation loss improved.
@@ -27,6 +27,12 @@ class EarlyStopping:
         self.best_model = None
         self.best_optimizer_state_dict = None
         self.best_performance_results = None
+        
+        self.delta_best_score = None
+        self.delta_best_epoch = None
+        self.delta_best_model = None
+        self.delta_best_optimizer_state_dict = None
+        self.delta_best_performance_results = None
 
         if True in [
             m in self.metric_to_track
@@ -78,10 +84,54 @@ class EarlyStopping:
                 )
             if self.counter >= self.patience:
                 self.early_stop_flag = True
+                
+            if not (score <= self.best_score):
+                self.delta_best_score = score
+                self.delta_best_epoch = epoch
+                self.delta_best_model = model
+                self.delta_best_performance_results = performance_results
+                self.delta_best_optimizer_state_dict = optimizer_state_dict
         else:
             self.best_score = score
             self.best_epoch = epoch
             self.best_model = model
             self.best_performance_results = performance_results
             self.best_optimizer_state_dict = optimizer_state_dict
-            self.counter = 0
\ No newline at end of file
+            self.counter = 0
+            
+            self.delta_best_score = None
+            self.delta_best_epoch = None
+            self.delta_best_model = None
+            self.delta_best_performance_results = None
+            self.delta_best_optimizer_state_dict = None
+            
+            
+    def get_best_score(self):
+        if self.delta_best_score is None:
+            return self.best_score
+        else:
+            return self.delta_best_score
+        
+    def get_best_epoch(self):
+        if self.delta_best_epoch is None:
+            return self.best_epoch
+        else:
+            return self.delta_best_epoch
+        
+    def get_best_model(self):
+        if self.delta_best_model is None:
+            return self.best_model
+        else:
+            return self.delta_best_model
+        
+    def get_best_performance_results(self):
+        if self.delta_best_performance_results is None:
+            return self.best_performance_results
+        else:
+            return self.delta_best_performance_results
+        
+    def get_best_optimizer_state_dict(self):
+        if self.delta_best_optimizer_state_dict is None:
+            return self.best_optimizer_state_dict
+        else:
+            return self.delta_best_optimizer_state_dict
\ No newline at end of file
